/*
 * libxfdashboard: Maybe a Gnome shell like dashboard for Xfce
 *
 * Copyright 2012-2021 Stephan Haller <nomad@froevel.de>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 *
 *
 */

#ifndef __LIBXFDASHBOARD_H__
#define __LIBXFDASHBOARD_H__

#define __LIBXFDASHBOARD_H_INSIDE__

#include <libxfdashboard/action-button.h>
#include <libxfdashboard/actor.h>
#include <libxfdashboard/animation.h>
#include <libxfdashboard/application-button.h>
#include <libxfdashboard/application-database.h>
#include <libxfdashboard/application-tracker.h>
#include <libxfdashboard/applications-menu-model.h>
#include <libxfdashboard/applications-search-provider.h>
#include <libxfdashboard/applications-view.h>
#include <libxfdashboard/background.h>
#include <libxfdashboard/binding.h>
#include <libxfdashboard/bindings-pool.h>
#include <libxfdashboard/box-layout.h>
#include <libxfdashboard/button.h>
#include <libxfdashboard/click-action.h>
#include <libxfdashboard/collapse-box.h>
#include <libxfdashboard/core.h>
#include <libxfdashboard/css-selector.h>
#include <libxfdashboard/debug.h>
#include <libxfdashboard/desktop-app-info.h>
#include <libxfdashboard/desktop-app-info-action.h>
#include <libxfdashboard/drag-action.h>
#include <libxfdashboard/drop-action.h>
#include <libxfdashboard/dynamic-table-layout.h>
#include <libxfdashboard/emblem-effect.h>
#include <libxfdashboard/fill-box-layout.h>
#include <libxfdashboard/focusable.h>
#include <libxfdashboard/focus-manager.h>
#include <libxfdashboard/gradient-color.h>
#include <libxfdashboard/image-content.h>
#include <libxfdashboard/label.h>
#include <libxfdashboard/live-window.h>
#include <libxfdashboard/live-window-simple.h>
#include <libxfdashboard/live-workspace.h>
#include <libxfdashboard/model.h>
#include <libxfdashboard/outline-effect.h>
#include <libxfdashboard/plugin.h>
#include <libxfdashboard/plugin-settings.h>
#include <libxfdashboard/plugins-manager.h>
#include <libxfdashboard/popup-menu.h>
#include <libxfdashboard/popup-menu-item.h>
#include <libxfdashboard/popup-menu-item-button.h>
#include <libxfdashboard/popup-menu-item-separator.h>
#include <libxfdashboard/quicklaunch.h>
#include <libxfdashboard/scaled-table-layout.h>
#include <libxfdashboard/scrollbar.h>
#include <libxfdashboard/search-manager.h>
#include <libxfdashboard/search-provider.h>
#include <libxfdashboard/search-result-container.h>
#include <libxfdashboard/search-result-set.h>
#include <libxfdashboard/search-view.h>
#include <libxfdashboard/settings.h>
#include <libxfdashboard/stage.h>
#include <libxfdashboard/stage-interface.h>
#include <libxfdashboard/stylable.h>
#include <libxfdashboard/text-box.h>
#include <libxfdashboard/theme.h>
#include <libxfdashboard/theme-animation.h>
#include <libxfdashboard/theme-css.h>
#include <libxfdashboard/theme-effects.h>
#include <libxfdashboard/theme-layout.h>
#include <libxfdashboard/toggle-button.h>
#include <libxfdashboard/tooltip-action.h>
#include <libxfdashboard/transition-group.h>
#include <libxfdashboard/types.h>
#include <libxfdashboard/utils.h>
#include <libxfdashboard/version.h>
#include <libxfdashboard/view.h>
#include <libxfdashboard/view-manager.h>
#include <libxfdashboard/viewpad.h>
#include <libxfdashboard/view-selector.h>
#include <libxfdashboard/window-content.h>
#include <libxfdashboard/windows-view.h>
#include <libxfdashboard/window-tracker.h>
#include <libxfdashboard/window-tracker-backend.h>
#include <libxfdashboard/window-tracker-monitor.h>
#include <libxfdashboard/window-tracker-window.h>
#include <libxfdashboard/window-tracker-workspace.h>
#include <libxfdashboard/workspace-selector.h>

#undef __LIBXFDASHBOARD_H_INSIDE__

#endif
